@@ -754,7 +754,7 @@ class SDVPN(object):
                 + self.surface_energy(x, disregistry))
     
     def check_energies(self, x=None, disregistry=None, 
-                       energyperlength_unit='eV/angstrom'):
+                       energyperlength_unit='eV/Å'):
         """
         Prints a summary string of all computed energy components.
 
@@ -765,6 +765,9 @@ class SDVPN(object):
         disregistry : numpy.ndarray, optional
             (N, 3) shaped array of disregistry vectors at each x-coordinate.
             Default value is the stored disregistry values.
+        energyperlength_unit : str, optional
+            The units of energy per length to report the dislocation line
+            energies in.  Default value is 'eV/Å'.
         """
         hasvals = True
         # Default values are class properties
@@ -792,7 +795,7 @@ class SDVPN(object):
             print('x and disregistry must be set/given to check energies')
     
     def disregistry_plot(self, x=None, disregistry=None, figsize=None,
-                         length_unit='angstrom'):
+                         length_unit='Å'):
         """
         Creates a simple matplotlib figure showing the disregistry profiles.
 
@@ -805,7 +808,10 @@ class SDVPN(object):
             Default value is the stored disregistry values.
         figsize : tuple, optional
             matplotlib figure figsize parameter.  Default value is (10, 6).
-
+        length_unit : str, optional
+            The unit of length to display positions and disregistry values in.
+            Default value is 'Å'.
+            
         Returns
         -------
         matplotlib.pyplot.figure
@@ -830,12 +836,15 @@ class SDVPN(object):
                 figsize = (10, 6)
 
             fig = plt.figure(figsize=figsize)
+            
+            x = uc.get_in_units(x, length_unit)
+            disregistry = uc.get_in_units(disregistry, length_unit)
             plt.plot(x, disregistry[:, 0], label='edge disregistry')
             plt.plot(x, disregistry[:, 1], label='normal disregistry')
             plt.plot(x, disregistry[:, 2], label='screw disregistry')
             plt.legend(fontsize='xx-large')
-            plt.xlabel('x (Å)', size='xx-large')
-            plt.ylabel('disregistry (Å)', size='xx-large')
+            plt.xlabel(f'x (${length_unit}$)', size='xx-large')
+            plt.ylabel(f'disregistry (${length_unit}$', size='xx-large')
             return fig
 
         else:
@@ -844,7 +853,7 @@ class SDVPN(object):
     def E_gsf_surface_plot(self, x=None, disregistry=None, fmt='ro-',
                            normalize=False, smooth=True, 
                            a1vect=None, a2vect=None, xvect=None,
-                           length_unit='angstrom', energyperarea_unit='eV/angstrom^2',
+                           length_unit='Å', energyperarea_unit='eV/Å^2',
                            numx=100, numy=100, figsize=None, **kwargs):
         """
         Extends the GammaSurface.E_gsf_surface_plot() method to plot the
@@ -883,10 +892,10 @@ class SDVPN(object):
             of a1vect.
         length_unit : str, optional
             The unit of length to display non-normalized axes values in.
-            Default value is 'angstrom'.
+            Default value is 'Å'.
         energyperarea_unit : str, optional
             The unit of energy per area to display the stacking fault energies
-            in. Default value is 'eV/angstrom^2'.
+            in. Default value is 'eV/Å^2'.
         numx : int, optional
             The number of plotting points to use along the x-axis.  Default
             value is 100.
@@ -904,7 +913,9 @@ class SDVPN(object):
             
         Returns
         -------
-        matplotlib.figure
+        matplotlib.pyplot.figure
+            The generated figure allowing users to perform additional
+            modifications.
         """
 
         # Generate the surface plot
@@ -938,15 +949,44 @@ class SDVPN(object):
             
             # Transform to x, y plotting coordinates and plot
             x, y = self.gamma.pos_to_xy(pos, xvect=xvect)
+            x = uc.get_in_units(x, length_unit)
+            y = uc.get_in_units(y, length_unit)
             plt.plot(x, y, fmt)
 
         return fig
 
     def E_gsf_vs_x_plot(self, x=None, disregistry=None, figsize=None, 
-                        length_unit='angstrom', energyperarea_unit='eV/angstrom^2'):
+                        length_unit='Å', energyperarea_unit='eV/Å^2'):
         """
-        Generates a plot of the stacking fault energy associated with the
-        disregistry values for each x coordinate.
+        Generates a plot of the stacking fault energy, i.e. misfit energy,
+        associated with the disregistry values for each x coordinate.
+        
+        Parameters
+        ----------
+        x : numpy.ndarray, optional
+            x-coordinates.  Default value is the stored x-coordinates. If x
+            or disregistry are not set/given, then the disregistry path will
+            not be added.
+        disregistry : numpy.ndarray, optional
+            (N, 3) shaped array of disregistry vectors at each x-coordinate.
+            Default value is the stored disregistry values.  If x
+            or disregistry are not set/given, then the disregistry path will
+            not be added.
+        figsize : tuple or None, optional
+            The figure's x,y dimensions.  If None (default), then a figure
+            size of (10, 6) will be generated.
+        length_unit : str, optional
+            The unit of length to display x coordinates in.  Default value is
+            'Å'.
+        energyperarea_unit : str, optional
+            The unit of energy per area to display the stacking fault energies
+            in. Default value is 'eV/Å^2'.
+            
+        Returns
+        -------
+        matplotlib.pyplot.figure
+            The generated figure allowing users to perform additional
+            modifications.
         """
         hasvals = True
         # Default values are class properties
@@ -970,8 +1010,8 @@ class SDVPN(object):
             fig = plt.figure(figsize=figsize)
             plt.plot(uc.get_in_units(x, length_unit),
                      uc.get_in_units(gsf, energyperarea_unit))
-            plt.xlabel(f'x-coordinate ({length_unit})', size='xx-large')
-            plt.ylabel(f'Stacking fault energy ({energyperarea_unit})', size='xx-large')
+            plt.xlabel(f'x-coordinate (${length_unit}$)', size='xx-large')
+            plt.ylabel(f'Stacking fault energy (${energyperarea_unit}$)', size='xx-large')
             return fig
         
         else:
@@ -986,8 +1026,15 @@ class SDVPN(object):
         ----------
         model : str or DataModelDict
             The semi-discrete-Peierls-Nabarro data model to load.
-        gamma : atomman.defect.GammaSurface
-            The gamma surface to use.
+        gamma : atomman.defect.GammaSurface, optional
+            The gamma surface to use.  If not given, will check to see if the
+            content is inside model.
+        
+        Raises
+        ------
+        ValueError
+            If the gamma surface information is not given and it is not found
+            in model.
         """
         
         # Identify model element
@@ -998,7 +1045,10 @@ class SDVPN(object):
         
         # Load calculation parameters
         params = sdpn['parameter']
-        self.__transform = uc.value_unit(params.get('transform', params['axes']))
+        try:
+            self.__transform = uc.value_unit(params['transform'])
+        except: 
+            self.__transform = uc.value_unit(params['axes'])
         self.__K_tensor = uc.value_unit(params['K_tensor'])
         self.__burgers = uc.value_unit(params['burgers'])
         self.tau = uc.value_unit(params['tau'])
@@ -1027,22 +1077,30 @@ class SDVPN(object):
         self.x = uc.value_unit(solution['x'])
         self.disregistry = uc.value_unit(solution['disregistry'])
     
-    def model(self, length_unit='angstrom', energy_unit='eV',
+    def model(self, length_unit='Å', energyperarea_unit='eV/Å^2',
               pressure_unit='GPa', include_gamma=False):
         """
         Generate a data model for the object.
         
         Parameters
         ----------
-        length_unit : str
-            The unit of length to save values as.  Default is 'angstrom'.
-        energy_unit : str
-            The unit of energy to save values as.  Default is 'eV'.
-        pressure_unit : str
+        length_unit : str, optional
+            The unit of length to save values as.  Default is 'Å'.
+        energyperarea_unit : str, optional
+            The unit of energy per area to save fault energy values as.  Only
+            used if the gamma surface information is included.  Default value
+            is 'eV/Å^2'.
+        pressure_unit : str, optional
             The unit of pressure to save values as.  Default is 'GPa'.
-        include_gamma : bool
+        include_gamma : bool, optional
             Flag indicating if the gamma surface data is to be included.
             Default value is False.
+            
+        Returns
+        -------
+        DataModelDict
+            The data model containing all input parameters and the current
+            disregistry vectors.
         """
         model = DM()
         model['semidiscrete-variational-Peierls-Nabarro'] = sdpn = DM()
@@ -1066,8 +1124,7 @@ class SDVPN(object):
         if include_gamma is True:
             sdpn['generalized-stacking-fault'] = self.gamma.model(
                                                   length_unit=length_unit,
-                                                  energy_unit=energy_unit,
-                                                  pressure_unit=pressure_unit)
+                                                  energyperarea_unit=energyperarea_unit)
         
         sdpn['solution'] = solution = DM()
         solution['x'] = uc.model(self.x, length_unit)
